/*==================================================================================================
*   Project              : RTD AUTOSAR 4.4
*   Platform             : CORTEXM
*   Peripheral           : S32K3XX
*   Dependencies         : none
*
*   Autosar Version      : 4.4.0
*   Autosar Revision     : ASR_REL_4_4_REV_0000
*   Autosar Conf.Variant :
*   SW Version           : 1.0.0
*   Build Version        : S32K3_RTD_1_0_0_D2110_ASR_REL_4_4_REV_0000_20211007
*
*   (c) Copyright 2020 - 2021 NXP Semiconductors
*   All Rights Reserved.
*
*   NXP Confidential. This software is owned or controlled by NXP and may only be
*   used strictly in accordance with the applicable license terms. By expressly
*   accepting such terms or by downloading, installing, activating and/or otherwise
*   using the software, you are agreeing that you have read, and that you agree to
*   comply with and are bound by, such license terms. If you do not agree to be
*   bound by the applicable license terms, then you may not retain, install,
*   activate or otherwise use the software.
==================================================================================================*/

/**
*   @file main.c
*
*   @addtogroup main_module main module documentation
*   @{
*/

/* Including necessary configuration files. */
#include "Mcal.h"
#include "CAN.h"
#include "SchM_Can.h"
#include "Mcu.h"
#include "Mcl.h"
#include "Port.h"
#include "Dio.h"
#include "Uart.h"
#include "Platform.h"
#include "Lpuart_Uart_Ip_Irq.h"
#include "Flexio_Uart_Ip_Irq.h"

//extern ISR(CAN0_ORED_IRQHandler);
//extern ISR(CAN0_ORED_0_31_MB_IRQHandler);
//extern ISR(CAN0_ORED_32_63_MB_IRQHandler);
//extern ISR(CAN0_ORED_64_95_MB_IRQHandler);
//extern ISR(CAN1_ORED_IRQHandler);
//extern ISR(CAN1_ORED_0_31_MB_IRQHandler);
//extern ISR(CAN1_ORED_32_63_MB_IRQHandler);






/* User includes */

#include <string.h>


#define UART_LPUART0_RS232  0
#define FLEXIO_RX  1
#define FLEXIO_TX  2
#define UART_LPUART1_WIFI  3
#define UART_LPUART2_BT  4
//#define UART_LPUART6_RS485  3


/* Welcome messages displayed at the console */
#define WELCOME_MSG_1 "abcdefghijk?\r\n"
#define WELCOME_MSG_2 "123345678\r\n"

/* Error message displayed at the console, in case data is received erroneously */
#define ERROR_MSG "An error occurred! The application will stop!\r\n"

/* Length of the message to be received from the console */
#define MSG_LEN  50U
#define TJA1153_START_ID   (uint32_t)(0x555u)
#define TJA1153_CONFIG_ID  (uint32_t)(0x18DA00F1u)

/*==================================================================================================
*                          LOCAL TYPEDEFS (STRUCTURES, UNIONS, ENUMS)
==================================================================================================*/


/*==================================================================================================
*                                       LOCAL MACROS
==================================================================================================*/


/*==================================================================================================
*                                      LOCAL CONSTANTS
==================================================================================================*/


/*==================================================================================================
*                                      LOCAL VARIABLES
==================================================================================================*/


/*==================================================================================================
*                                      GLOBAL CONSTANTS
==================================================================================================*/

uint8 Can_au8Sdu8bytes[8U] = {0x01U, 0x02U, 0x03U, 0x04U, 0x05U, 0x06U, 0x07U, 0x08};
volatile uint8 pinValue = STD_LOW;
uint8 dummyData[64] = {1,2,3,4,5,6,7,8};
/*==================================================================================================
*                                      GLOBAL VARIABLES
==================================================================================================*/
uint8 CanIf_u8TxConfirmCnt = 0U;
boolean CanIf_bTxFlag = FALSE;
uint8 CanIf_u8RxIndicationCnt = 0U;
boolean CanIf_bRxFlag = FALSE;

#if 1
static const Flexcan_Ip_DataInfoType CAN_TJA1153_MB_Config_1 = {
		.data_length = 0u,
		.msg_id_type = FLEXCAN_MSG_ID_STD,
		.is_polling  = true
};

/* Configure TJA1153 sproofing protection, 0x10 command byte */
static const Flexcan_Ip_DataInfoType TJA1153_SpoofingProtect_Config_Form = {
		.data_length = 6u,
		.msg_id_type = FLEXCAN_MSG_ID_EXT,
		.is_polling  = true
};

/* Configure TJA1153 flooding and tamper protection, 0x40 command byte */
static const Flexcan_Ip_DataInfoType TJA1153_FloodTamperProt_Config_Form = {
		.data_length = 2u,
		.msg_id_type = FLEXCAN_MSG_ID_STD,
		.is_polling  = true
};

/* Configure bit time, secure mode timeout, blacklist, etc. 0x50 command byte */
static const Flexcan_Ip_DataInfoType TJA1153_BitTimeLength_Config_Form = {
		.data_length = 3u,
		.msg_id_type = FLEXCAN_MSG_ID_STD,
		.is_polling  = true
};

/* Configure TJA1153 command message id, 0x60 command byte */
static const Flexcan_Ip_DataInfoType TJA1153_CommandMessageID_Config_Form = {
		.data_length = 5u,
		.msg_id_type = FLEXCAN_MSG_ID_STD,
		.is_polling  = true
};

/* Configure TJA1153 leaving configuration mode message format, 0x71, 0x72, 0x74 command byte */
static const Flexcan_Ip_DataInfoType TJA1153_LeaveConfigMode_Config_Form = {
		.data_length = 8u,
		.msg_id_type = FLEXCAN_MSG_ID_STD,
		.is_polling  = true
};

/* Configure TJA1153 verification of configure message, 0xF0 command byte */
static const Flexcan_Ip_DataInfoType TJA1153_ConfigVerify_Config_Form = {
		.data_length = 3u,
		.msg_id_type = FLEXCAN_MSG_ID_STD,
		.is_polling  = true
};
#endif
/*==================================================================================================
*                                   LOCAL FUNCTION PROTOTYPES
==================================================================================================*/
void TestDelay(uint32 delay);

/*==================================================================================================
*                                       LOCAL FUNCTIONS
==================================================================================================*/


/*==================================================================================================
*                                       GLOBAL FUNCTIONS
==================================================================================================*/
#if 1
void CanIf_ControllerBusOff(uint8 ControllerId)
{
    (void)ControllerId;
}

void CanIf_ControllerModeIndication(uint8 ControllerId, Can_ControllerStateType ControllerMode )
{
    (void)ControllerId;
    (void)ControllerMode;
}
void CanIf_TxConfirmation(PduIdType CanTxPduId)
{
    CanIf_u8TxConfirmCnt++;
    CanIf_bTxFlag = TRUE;
    (void)CanTxPduId;
}

void CanIf_RxIndication(const Can_HwType* Mailbox, const PduInfoType* PduInfoPtr )
{
    CanIf_u8RxIndicationCnt++;
    CanIf_bRxFlag = TRUE;
    (void)Mailbox;
    (void)PduInfoPtr;
}

void Can_DummyDelay(uint32 loops)
{
    VAR( volatile uint32, CAN_VAR) data = 0xAA55AA55;
    VAR( volatile uint32, CAN_VAR) contor1 = 0;
    VAR( volatile uint32, CAN_VAR) contor2 = loops;

    do
    {
        for (contor1 = 0; contor1 < 0x2FF; contor1++)
        {
            data ^= (1 << contor1) | (0xAAAAAA | contor2);
        }
        contor2--;
    } while( contor2 > 0);
}



Can_PduType Can_CreatePduInfo(Can_IdType id, PduIdType swPduHandle, uint8 length, uint8* sdu)
{
    Can_PduType PduInfo;

    PduInfo.id = id;
    PduInfo.swPduHandle = swPduHandle;
    PduInfo.length = length;
    PduInfo.sdu = sdu;

    return PduInfo;
}
#endif
#if 0
void My_Tja1153_Init(void)
{
		//Dio_WriteChannel(DioConf_DioChannel_PTC21_GPIO_OUT_MCU_CAN0_EN,1);
		//Dio_WriteChannel(DioConf_DioChannel_PTC20_GPIO_OUT_MCU_CAN0_STB,0);

		/* Send a classical frame with ID 0x555 */
		dummyData[0] = 0x00;
		dummyData[1] = 0x00;
		dummyData[2] = 0x00;
		dummyData[3] = 0x00;
		dummyData[4] = 0x00;
		dummyData[5] = 0x00;
		dummyData[6] = 0x00;
		dummyData[7] = 0x00;
		FlexCAN_Ip_SendBlocking(CanController_0, CanHardwareObject_0, \
			&CAN_TJA1153_MB_Config_1, TJA1153_START_ID, (uint8 *)&dummyData, 1000);

		/* Configure the sproofing protection*/
		dummyData[0] = 0x10;
		dummyData[1] = 0x01;   /* White list element 1*/
		dummyData[2] = 0x51;
		dummyData[3] = 0x00;   /* ID + mask, 0x100 + 0x000, any standard frame can be sent*/
		dummyData[4] = 0x07;
		dummyData[5] = 0xFF;
		FlexCAN_Ip_SendBlocking(CanController_0, CanHardwareObject_0, \
				&TJA1153_SpoofingProtect_Config_Form, TJA1153_CONFIG_ID, (uint8 *)&dummyData, 1000);

		dummyData[0] = 0x10 + 0x80;
		FlexCAN_Ip_SendBlocking(CanController_0, CanHardwareObject_0, \
				&TJA1153_SpoofingProtect_Config_Form, TJA1153_CONFIG_ID, (uint8 *)&dummyData, 1000);

		/* Configure the flood tamper protection */
		dummyData[0] = 0x40;
		dummyData[1] = 0x00;
		FlexCAN_Ip_SendBlocking(CanController_0, CanHardwareObject_0, \
				&TJA1153_FloodTamperProt_Config_Form, TJA1153_CONFIG_ID, (uint8 *)&dummyData, 1000);

		/* Validate the configuration */
		dummyData[0] = 0xC0;
		dummyData[1] = 0x00;
		FlexCAN_Ip_SendBlocking(CanController_0, CanHardwareObject_0, \
				&TJA1153_FloodTamperProt_Config_Form, TJA1153_CONFIG_ID, (uint8 *)&dummyData, 1000);

		/* Configure bit time and blacklist, etc */
		dummyData[0] = 0x50;
		dummyData[1] = 0x38;
		dummyData[2] = 0xAB;

		FlexCAN_Ip_SendBlocking(CanController_0, CanHardwareObject_0, \
				&TJA1153_BitTimeLength_Config_Form, TJA1153_CONFIG_ID, (uint8 *)&dummyData, 1000);

		/* Validate the configuration */
		dummyData[0] = 0xD0;
		dummyData[1] = 0x38;
		dummyData[2] = 0xAB;
		FlexCAN_Ip_SendBlocking(CanController_0, CanHardwareObject_0, \
				&TJA1153_BitTimeLength_Config_Form, TJA1153_CONFIG_ID, (uint8 *)&dummyData, 1000);

		/* Configure the device ID */
		dummyData[0] = 0x60;
		dummyData[1] = 0x98;
		dummyData[2] = 0xDA;
		dummyData[3] = 0x00;
		dummyData[4] = 0xF1;
		FlexCAN_Ip_SendBlocking(CanController_0, CanHardwareObject_0, \
				&TJA1153_CommandMessageID_Config_Form, TJA1153_CONFIG_ID, (uint8 *)&dummyData, 1000);

		/* Validate the configuration */
		dummyData[0] = 0xE0;
		dummyData[1] = 0x98;
		dummyData[2] = 0xDA;
		dummyData[3] = 0x00;
		dummyData[4] = 0xF1;
		FlexCAN_Ip_SendBlocking(CanController_0, CanHardwareObject_0, \
				&TJA1153_CommandMessageID_Config_Form, TJA1153_CONFIG_ID, (uint8 *)&dummyData, 1000);

		/* Validate */
		dummyData[0] = 0xF0;
		dummyData[1] = 0x00;
		dummyData[2] = 0x00;
		dummyData[3] = 0x00;
		dummyData[4] = 0x00;
		FlexCAN_Ip_SendBlocking(CanController_0, CanHardwareObject_0, \
				&TJA1153_ConfigVerify_Config_Form, TJA1153_CONFIG_ID, (uint8 *)&dummyData, 1000);

		/* Leave the configuration mode and do not save it to NVM, after next power up, need to initialize again */
		dummyData[0] = 0x71;
		dummyData[1] = 0x02;
		dummyData[2] = 0x03;
		dummyData[3] = 0x04;
		dummyData[4] = 0x05;
		dummyData[5] = 0x06;
		dummyData[6] = 0x07;
		dummyData[7] = 0x08;
		FlexCAN_Ip_SendBlocking(CanController_0, CanHardwareObject_0, \
				&TJA1153_LeaveConfigMode_Config_Form, TJA1153_CONFIG_ID, (uint8 *)&dummyData, 1000);

		/* Change STB_N and EN pin to 1, enable the normal mode of TJA1153 */
		//Dio_WriteChannel(DioConf_DioChannel_PTC21_GPIO_OUT_MCU_CAN0_EN,1);
		//Dio_WriteChannel(DioConf_DioChannel_PTC20_GPIO_OUT_MCU_CAN0_STB,1);

}
#endif

void TestDelay(uint32 delay)
{
    static volatile uint32 DelayTimer = 0;
    while(DelayTimer<delay)
    {
        DelayTimer++;
    }
    DelayTimer=0;
}

boolean User_Str_Cmp(const uint8 * pBuffer1, const uint8 * pBuffer2, const uint32 length)
{
    uint32 idx = 0;
    for (idx = 0; idx < length; idx++)
    {
        if(pBuffer1[idx] != pBuffer2[idx])
        {
            return FALSE;
        }
    }
    return TRUE;
}



//Std_ReturnType Send_Data(uint8 transChannel, const uint8* pBuffer, uint32 length, uint32 timeOut)
//{
//    volatile Std_ReturnType T_Uart_Status;
//    volatile Uart_StatusType Uart_ReceiveStatus = UART_STATUS_TIMEOUT;
//    volatile Uart_StatusType Uart_TransmitStatus = UART_STATUS_TIMEOUT;
//    uint32 T_bytesRemaining;
//    //uint32 T_timeout = 0xFFFFFF;
//    uint8 Rx_Buffer[MSG_LEN];
//
//    /* Uart_AsyncReceive transmit data */
//    //T_Uart_Status = Uart_AsyncReceive(recvChannel, Rx_Buffer, length);
//    //if (E_OK != T_Uart_Status)
//    //{
//    //    return E_NOT_OK;
//    //}
//    /* Uart_AsyncSend transmit data */
//    T_Uart_Status = Uart_AsyncSend(transChannel, pBuffer, length);
//    if (E_OK != T_Uart_Status)
//	{
//	    return E_NOT_OK;
//	}
//
//    /* Check for no on-going transmission */
//    do
//    {
//        Uart_TransmitStatus = Uart_GetStatus(transChannel, &T_bytesRemaining, UART_SEND);
//    } while (UART_STATUS_NO_ERROR != Uart_TransmitStatus && 0 < timeOut--);
//
//    //T_timeout = 0xFFFFFF;
//
//    //do
//    //{
//    //    Uart_ReceiveStatus = Uart_GetStatus(recvChannel, &T_bytesRemaining, UART_RECEIVE);
//    //} while (UART_STATUS_NO_ERROR != Uart_ReceiveStatus && 0 < T_timeout--);
//
//    if ((UART_STATUS_NO_ERROR != Uart_TransmitStatus)) //|| (UART_STATUS_NO_ERROR != Uart_ReceiveStatus))
//    {
//        return E_NOT_OK;
//    }
//
////    if(User_Str_Cmp(pBuffer, (const uint8 *)Rx_Buffer, length) == FALSE)
////    {
////        return E_NOT_OK;
////    }
//
//    return E_OK;
//}

Std_ReturnType Send_Data(uint8 transChannel, uint8 recvChannel, const uint8* pBuffer, uint8* Rx_Buffer, uint32 length, uint32 T_timeout)
{
    volatile Std_ReturnType T_Uart_Status;
    volatile Uart_StatusType Uart_ReceiveStatus = UART_STATUS_TIMEOUT;
    volatile Uart_StatusType Uart_TransmitStatus = UART_STATUS_TIMEOUT;
    uint32 T_bytesRemaining;
    uint32 timeout = T_timeout;
//    uint8 Rx_Buffer[MSG_LEN];

    /* Uart_AsyncReceive transmit data */
    T_Uart_Status = Uart_AsyncReceive(recvChannel, Rx_Buffer, length+10);
    if (E_OK != T_Uart_Status)
    {
        return E_NOT_OK;
    }
    /* Uart_AsyncSend transmit data */
    T_Uart_Status = Uart_AsyncSend(transChannel, pBuffer, length);
    if (E_OK != T_Uart_Status)
    {
        return E_NOT_OK;
    }

    /* Check for no on-going transmission */
    do
    {
        Uart_TransmitStatus = Uart_GetStatus(transChannel, &T_bytesRemaining, UART_SEND);
    } while (UART_STATUS_NO_ERROR != Uart_TransmitStatus && 0 < timeout--);

    timeout = T_timeout;

    do
    {
        Uart_ReceiveStatus = Uart_GetStatus(recvChannel, &T_bytesRemaining, UART_RECEIVE);
    } while (UART_STATUS_NO_ERROR != Uart_ReceiveStatus && 0 < timeout--);

    if ((UART_STATUS_NO_ERROR != Uart_TransmitStatus) || (UART_STATUS_NO_ERROR != Uart_ReceiveStatus))
    {
    	Uart_Abort(recvChannel,UART_RECEIVE);
    	Uart_Abort(recvChannel,UART_SEND);
        return E_NOT_OK;
    }

    if(User_Str_Cmp(pBuffer, (const uint8 *)Rx_Buffer, length) == FALSE)
    {
        return E_NOT_OK;
    }

    return E_OK;
}

Std_ReturnType Rece_Data(uint8 recvChannel, const uint8* pBuffer, uint32 length, uint32 timeOut)
{
    volatile Std_ReturnType T_Uart_Status;
    volatile Uart_StatusType Uart_ReceiveStatus = UART_STATUS_TIMEOUT;
    //volatile Uart_StatusType Uart_TransmitStatus = UART_STATUS_TIMEOUT;
    uint32 T_bytesRemaining;
    //uint32 T_timeout = 0xFFFFFF;
    //uint8 Rx_Buffer[MSG_LEN];

    /* Uart_AsyncReceive transmit data */
    T_Uart_Status = Uart_AsyncReceive(recvChannel, pBuffer, length);
    if (E_OK != T_Uart_Status)
	{
		return E_NOT_OK;
	}
    /* Uart_AsyncSend transmit data */


    //T_timeout = 0xFFFFFF;

    do
    {
        Uart_ReceiveStatus = Uart_GetStatus(recvChannel, &T_bytesRemaining, UART_RECEIVE);
    } while ((UART_STATUS_NO_ERROR != Uart_ReceiveStatus) && (0<timeOut--) );

    if ((UART_STATUS_NO_ERROR != Uart_ReceiveStatus))
    {
    	Uart_Abort(recvChannel,UART_RECEIVE);
        return E_NOT_OK;
    }

//    if(User_Str_Cmp(pBuffer, (const uint8 *)Rx_Buffer, length) == FALSE)
//    {
//        return E_NOT_OK;
//    }

    return E_OK;
}
/*!
  \brief The main function for the project.
  \details The startup initialization sequence is the following:
 * - startup asm routine
 * - main()
*/
int main(void)
{
    /* Write your code here */
	volatile Std_ReturnType T_Uart_Status1;
	volatile Std_ReturnType T_Uart_Status2;
	volatile Std_ReturnType R_Uart_Status1;
	volatile Std_ReturnType R_Uart_Status2;
	static Can_PduType Can_PduInfo;
	static Can_PduType Can_PduInfo1;
	volatile Std_ReturnType CAN_Write_Status;
	uint8 rxBuffer[100];

	uint8 u8TimeOut = 100U;
	CanIf_bTxFlag = FALSE;
	CanIf_bRxFlag = FALSE;



    /* Initialize the Mcu driver */
#if (MCU_PRECOMPILE_SUPPORT == STD_ON)
    Mcu_Init(NULL_PTR);
#elif (MCU_PRECOMPILE_SUPPORT == STD_OFF)
    Mcu_Init(&Mcu_Config_VS_0);
#endif /* (MCU_PRECOMPILE_SUPPORT == STD_ON) */

	Mcu_InitClock(McuClockSettingConfig_0);

	/* Wait until PLL is locked */
	//while ( MCU_PLL_LOCKED != Mcu_GetPllStatus() )
	{
		/* Busy wait until the System PLL is locked */
	}
	//Mcu_DistributePllClock();
	/* Initialize Mcl module */
	Mcl_Init(NULL_PTR);

	Mcu_SetMode(McuModeSettingConf_0);
	OsIf_Init(NULL_PTR);
	Platform_Init(NULL_PTR);
    Platform_InstallIrqHandler(LPUART0_RxTx_IRQn, LPUART_UART_IP_0_IRQHandler, NULL_PTR);
    Platform_InstallIrqHandler(FLEXIO_IRQn, MCL_FLEXIO_ISR, NULL_PTR);

	/* Initialize all pins*/
#if(PORT_PRECOMPILE_SUPPORT == STD_ON)
	Port_Init(NULL_PTR);
#elif(PORT_PRECOMPILE_SUPPORT == STD_OFF)
	Port_Init(&Port_Config_VS_0);
#endif

	/* Initializes an UART driver*/
#if (UART_PRECOMPILE_SUPPORT == STD_ON)
	Uart_Init(NULL_PTR);
#elif(UART_PRECOMPILE_SUPPORT == STD_OFF)
	Uart_Init(&Uart_xConfig_VS_0);
#endif



#if 1	/* Initialize Platform driver */


#if (CAN_PRECOMPILE_SUPPORT == STD_ON)
	Can_Init(NULL_PTR);
#elif(CAN_PRECOMPILE_SUPPORT == STD_OFF)
	Can_Init(&Can_Config_VS_0);
#endif


#endif
#if 0
	Platform_InstallIrqHandler(FlexCAN0_0_IRQn, CAN0_ORED_IRQHandler, NULL);
	Platform_SetIrq(FlexCAN0_0_IRQn, TRUE);
	Platform_InstallIrqHandler(FlexCAN0_1_IRQn, CAN0_ORED_0_15_MB_IRQHandler, NULL);
	Platform_SetIrq(FlexCAN0_1_IRQn, TRUE);
	Platform_InstallIrqHandler(FlexCAN0_2_IRQn, CAN0_ORED_16_31_MB_IRQHandler, NULL);
	Platform_SetIrq(FlexCAN0_2_IRQn, TRUE);


//	Platform_InstallIrqHandler(FlexCAN1_0_IRQn, CAN1_ORED_IRQHandler, NULL);
//	Platform_SetIrq(FlexCAN1_0_IRQn, TRUE);
//	Platform_InstallIrqHandler(FlexCAN0_1_IRQn, CAN1_ORED_0_31_MB_IRQHandler, NULL);
//	Platform_SetIrq(FlexCAN1_1_IRQn, TRUE);
//	Platform_InstallIrqHandler(FlexCAN1_2_IRQn, CAN1_ORED_32_63_MB_IRQHandler, NULL);
//	Platform_SetIrq(FlexCAN1_2_IRQn, TRUE);
#endif


	//Dio_WriteChannel(DioConf_DioChannel_LED, STD_HIGH);

	//Dio_WriteChannel(DioConf_DioChannel_DIO_TEST, value);
	/* Send greeting string 1 from Flexio_0_Tx */
	//T_Uart_Status1 = Send_Data(UART_LPUART0_INTERNAL_CHANNEL, (const uint8 *)WELCOME_MSG_1, strlen(WELCOME_MSG_1));

	/* Send greeting string 2 from Flexio_0_Tx */
	//T_Uart_Status2 = Send_Data(UART_LPUART0_INTERNAL_CHANNEL, (const uint8 *)WELCOME_MSG_2, strlen(WELCOME_MSG_2));

	/* Can_CreatePduInfo(id, swPduHandle,length, sdu) */
	Can_PduInfo = Can_CreatePduInfo(0x55U, 0U, 8U, Can_au8Sdu8bytes);
	Can_PduInfo1 = Can_CreatePduInfo(0x66U, 0U, 2U, Can_au8Sdu8bytes);
	  /* Initilize Can driver */

	//Can_Init(&Can_Config_VS_0);
	Can_SetControllerMode(CanController_0, CAN_CS_STARTED);
//	Can_SetControllerMode(CanController_1, CAN_CS_STARTED);
//	Dio_WriteChannel(DioConf_DioChannel_PTE4_GPIO_OUT_MCU_4G_POW_EN,STD_ON);  //ʹpower
//	Dio_WriteChannel(DioConf_DioChannel_PTB20_GPIO_OUT_MCU_4G_PWRKEY,STD_ON); //ʹ俪
	//TestDelay(5000000);
	//Dio_WriteChannel(DioConf_DioChannel_PTB20_GPIO_OUT_MCU_4G_PWRKEY,STD_OFF);

//	Dio_WriteChannel(DioConf_DioChannel_PTB19_GPIO_OUT_MCU_4G_DTR,STD_ON); //DTR 
//	TestDelay(80000000);
	//Dio_WriteChannel(DioConf_DioChannel_PTB19_GPIO_OUT_MCU_4G_DTR,STD_OFF); //DTR 

	//Dio_WriteChannel(DioConf_DioChannel_PTB19_GPIO_OUT_MCU_4G_DTR,STD_ON);
	//Dio_WriteChannel(DioConf_DioChannel_PTB18_GPIO_OUT_MCU_4G_RESET,STD_ON);
	//TestDelay(100000);
	//Dio_WriteChannel(DioConf_DioChannel_PTB18_GPIO_OUT_MCU_4G_RESET,STD_OFF);
	//DioConf_DioChannel_PTB18_GPIO_OUT_MCU_4G_RESET
	//My_Tja1153_Init();
	while (1)
	  {
		//Can_MainFunction_Write();
		//Can_MainFunction_Read();
		 /* Toggle the LED when the Gpt notification is called */

		  pinValue = ~pinValue;
//		  Dio_WriteChannel(DioConf_DioChannel_PTA29_GPIO_OUT_MCU_LED3,pinValue);
//		  Dio_WriteChannel(DioConf_DioChannel_DioChannel_LED0,pinValue);
//		  Dio_WriteChannel(DioConf_DioChannel_DioChannel_LED1,pinValue);
		  /* Uart_AsyncSend transmit data */
		  //(void)Uart_AsyncSend(UART_CHANNEL, (const uint8 *)WELCOME_MSG, strlen(WELCOME_MSG));
		  CAN_Write_Status = Can_Write(Can0HardwareObject_TX, &Can_PduInfo);
		  if(CAN_Write_Status == E_OK)
		  {
			  while((!CanIf_bTxFlag) && (u8TimeOut != 0U))
			  {
					Can_MainFunction_Write();
					Can_DummyDelay(100U);
					u8TimeOut--;
			  }
		  }
		  u8TimeOut = 100U;
		  CanIf_bTxFlag = false;

		  while((!CanIf_bRxFlag) && (u8TimeOut != 0U))
		  {
			  Can_MainFunction_Read();
			  Can_DummyDelay(100U);
			  u8TimeOut--;
		  }
		  u8TimeOut = 100U;
		  CanIf_bRxFlag = false;

//		  Can_Write(CanHardwareObject_3, &Can_PduInfo1);
		  //Can_MainFunction_Read();
		  memset(rxBuffer,0,100);
		  T_Uart_Status1 = Send_Data(UART_LPUART0_RS232,UART_LPUART0_RS232, (const uint8 *)WELCOME_MSG_1,rxBuffer, strlen(WELCOME_MSG_1),10000);
		  //TestDelay(1000);

//		  R_Uart_Status1 = Rece_Data(UART_LPUART0_RS232, rxBuffer, strlen(WELCOME_MSG_1),0xFFFF);
		  TestDelay(2000000);
		  memset(rxBuffer,0,100);
		  /* Send greeting string 2 from Flexio_0_Tx */
		  T_Uart_Status2 = Send_Data(UART_LPUART0_RS232,UART_LPUART0_RS232, (const uint8 *)WELCOME_MSG_2, rxBuffer, strlen(WELCOME_MSG_2),10000);
		  //TestDelay(1000);
//		  memset(rxBuffer,0,100);
//		  R_Uart_Status2 = Rece_Data(UART_LPUART0_RS232, rxBuffer, strlen(WELCOME_MSG_2),0xFFFF);
		  TestDelay(2000000);

	 }


}

/** @} */
